# Copyright (c) 2016, Tim Wentzlau
# Licensed under MIT

""" Named lists are lists that are located by name """

class NamedLists(object):
    def __init__(self):
        self.data = {}

    def add(self, list_name, object):
        if list_name in self.data:
            self.data[list_name] += [object]
        else:
            self.data[list_name] = [object]

    def get_list_names(self):
        result = []
        for key in self.data:
            result += [key]
        return result

    def get_list_data(self, list_name):
        if list_name in self.data:
            return self.data[list_name]
        return None

    def get_list_data_with_partial_key(self, list_name):
        items = any(key.startswith(list_name) for key in self.data)
        result = {}
        for item in items:
            result[item] = self.data[item]

        return result
		


# Copyright (c) 2017, Tim Wentzlau
# Licensed under MIT

class MotorSteering(object):
    """
    Control the speed and direction of two motors.
    """
    def __init__(self, left_motor, right_motor):
        self._left_motor = left_motor
        self._right_motor = right_motor
        self._adjust = 0

    @property
    def adjust(self):
        return self._adjust

    @adjust.setter
    def adjust(self, value):
        self._adjust = value

    def run(self, speed, direction, rotation=False):
        print("steering run:", speed, direction)
        new_speed = speed + self._adjust

        if rotation:
            relative_factor = 0
        else:
            relative_factor = 1

        left_speed = new_speed * (relative_factor - direction / 100)
        right_speed = new_speed * (relative_factor + direction / 100)

        self._left_motor.run(left_speed)
        self._right_motor.run(right_speed)
